@@ -58,6 +58,19 @@ if (FALSE) {
   res <- run_trials(trial, n_rep = 20, base_seed = 12345, sparse = FALSE)
   save_testdata(res, "binom__results__3_arms__common_control__equivalence__futility__softened")
 
+  # Binomial trial without common control, equivalence testing and actual stopping for equivalence
+  trial <- setup_trial_binom(
+    arms = c("A", "B"),
+    true_ys = c(0.25, 0.23),
+    fixed_probs = c(0.5, 0.5),
+    data_looks = 1:20 * 100,
+    randomised_at_looks = 1:20 * 100 + 100,
+    equivalence_prob = 0.8,
+    equivalence_diff = 0.03
+  )
+  res <- run_trials(trial, n_rep = 20, base_seed = 12345)
+  save_testdata(res, "binom__results__3_arms__no_control__equivalence__stopping")
+
   # Normally distributed outcome trial with common control, "matched" control
   # group allocation, multiple best arms, varying probability thresholds, and
   # additional info (by default)
@@ -97,5 +110,10 @@ if (FALSE) {
 
   res <- run_trials(trial, n_rep = 20, base_seed = 12345)
   save_testdata(res, "norm__results__3_arms__common_control__fixed__all_arms_fixed")
+
+  # Calibration object (settings to facilitate speed)
+  trial <- setup_trial_binom(arms = c("A", "B"), true_ys = c(0.5, 0.5), data_looks = 100, n_draws = 1000)
+  res <- calibrate_trial(trial_spec = trial, search_range = c(0.95, 0.9999), tol = 0.05, base_seed = 12345)
+  save_testdata(res, "binom___calibration___setup2_arms__no_difference___rar")
 }
 
